import { Extension } from '../../@codemirror/state';
import { EditorView } from '../../@codemirror/view';

/**
 * 只读区域范围接口
 */
export interface ReadOnlyRange {
    /**
     * 开始位置
     */
    start: number;
    /**
     * 结束位置
     */
    end: number;
}
/**
 * 编辑器变更事件数据
 */
export interface EditorChangeEvent {
    /**
     * 编辑器的新值
     */
    value: string;
    /**
     * 当前的只读区域范围
     */
    readOnlyRanges: ReadOnlyRange[];
}
/**
 * 基础编辑器属性接口
 */
export interface BaseEditorProps {
    /**
     * 编辑器的值
     */
    value: string;
    /**
     * 编辑器值变化时的回调函数
     */
    onChange?: (event: EditorChangeEvent) => void;
    /**
     * 编辑器高度，默认 '300px'
     */
    height?: string | number;
    /**
     * 是否禁用编辑器
     */
    disabled?: boolean;
    /**
     * 编辑器样式类名
     */
    className?: string;
    /**
     * 编辑器内联样式
     */
    style?: React.CSSProperties;
    /**
     * 占位文本
     */
    placeholder?: string;
    /**
     * 是否显示行号，默认为 true
     */
    showLineNumbers?: boolean;
    /**
     * 编辑器视图创建后的回调
     */
    onEditorViewCreated?: (view: EditorView) => void;
}
/**
 * 通用编辑器属性接口
 */
export interface EditorProps extends BaseEditorProps {
    /**
     * 编辑器扩展
     */
    extensions?: Extension[];
    /**
     * 编辑器语言
     */
    language?: string;
}
/**
 * SQL 编辑器属性接口
 */
export interface SQLEditorProps extends BaseEditorProps {
    /**
     * SQL 编辑器扩展
     */
    extensions?: Extension[];
    /**
     * 不可编辑区域范围
     */
    readOnlyRanges?: ReadOnlyRange[];
    /**
     * 是否内部管理只读区域（默认为true）
     */
    manageReadOnlyRanges?: boolean;
}
/**
 * JSON 编辑器属性接口
 */
export interface JSONEditorProps extends BaseEditorProps {
    /**
     * JSON 编辑器扩展
     */
    extensions?: Extension[];
    /**
     * 是否启用JSON格式化功能
     * 当为true时，初始加载和按下Alt+F (Mac上为Cmd+Alt+F) 时会自动格式化
     */
    enableFormatting?: boolean;
}
export type { Extension, EditorView };
